pub struct RuntimeSecretLeaseRequest {
pub key: String,
pub ttl_seconds: u64,
}Expand description
Declared runtime-broker secret lease input for brokers that can hold an upstream lease or token for the lifetime of a cell run.
Fields
key: Stringttl_seconds: u64Trait Implementations
Sourceimpl Clone for RuntimeSecretLeaseRequest
impl Clone for RuntimeSecretLeaseRequest
Sourcefn clone(&self) -> RuntimeSecretLeaseRequest
fn clone(&self) -> RuntimeSecretLeaseRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RuntimeSecretLeaseRequest
impl RefUnwindSafe for RuntimeSecretLeaseRequest
impl Send for RuntimeSecretLeaseRequest
impl Sync for RuntimeSecretLeaseRequest
impl Unpin for RuntimeSecretLeaseRequest
impl UnsafeUnpin for RuntimeSecretLeaseRequest
impl UnwindSafe for RuntimeSecretLeaseRequest